@@ -127,7 +127,7 @@ giza_open_device (const char *newDeviceName, const char *newPrefix)
  *  -GIZA_UNITS_INCHES     :- inches
  *  Other values cause an error message and are treated as GIZA_UNITS_DEVICE
  *
- * See also: giza_open_device
+ * See Also: giza_open_device
  */
 int
 giza_open_device_size (const char *newDeviceName, const char *newPrefix, double width, double height, int units)
@@ -257,6 +257,7 @@ giza_open_device_size (const char *newDeviceName, const char *newPrefix, double
    * These routines check for Dev[id].deviceOpen so we must set that */
   Dev[id].deviceOpen = 1;
   Dev[id].defaultBackgroundAlpha = 1.;
+  Dev[id].motion_callback = NULL;
 
   giza_set_text_background (-1);
   giza_start_prompting ();
@@ -316,7 +317,7 @@ int _giza_get_internal_id(int devid)
  * Output:
  *  -devid, as returned by giza_open_device
  *
- * See also: giza_open_device, giza_get_device_id
+ * See Also: giza_open_device, giza_get_device_id
  */
 void
 giza_get_device_id (int *devid)
@@ -333,7 +334,7 @@ giza_get_device_id (int *devid)
  * Input:
  *  -devid :- device id, as returned by giza_open_device
  *
- * See also: giza_get_device_id, giza_open_device
+ * See Also: giza_get_device_id, giza_open_device
  */
 void
 giza_select_device (int devid)
@@ -397,7 +398,7 @@ giza_flush_device (void)
  * the background. If no other actions have been performed since the device was
  * opened or the last call to giza_change_page the call is ignored.
  *
- * See also: giza_subpanel, giza_set_panel
+ * See Also: giza_subpanel, giza_set_panel
  */
 void
 giza_change_page (void)
@@ -542,9 +543,7 @@ giza_close_device (void)
 
 
 /**
- * Device: _giza_close_device_unchecked
- *
- * Synopsis: In order to be able to share the cleaning-up code between
+ * In order to be able to share the cleaning-up code between
  * giza_close_device() and giza_open_device_size() [when something fails
  * during the construction of a new device] the actual cleaning up code
  * is put in this internal function.
@@ -608,9 +607,7 @@ _giza_close_device_unchecked (void) {
 }
 
 /**
- * Device: _giza_init_device_struct
- *
- * Synopsis: resets the contents of a giza_device_t to a known state:
+ * Resets the contents of a giza_device_t to a known state:
  * the whole struct is zeroed out and .type is set to GIZA_DEVICE_IV.
  *
  * Note: this approach was chosen over having a static/const/global
@@ -724,6 +721,58 @@ giza_query_device (const char *querytype, char *returnval, int* rlen)
   return ierr;
 }
 
+/**
+ * Device: giza_set_motion_callback
+ *
+ * Synopsis: set a callback function to be called
+ *           during cursor movement (e.g. to print things).
+ *           Function should be of the form
+ *           void func(double *x, double *y)
+ *
+ * Input:
+ *  -func  :- The subroutine to be called
+ *
+ * See Also: giza_end_motion_callback
+ *
+ */
+int
+giza_set_motion_callback (void (*func)(double *x, double *y, int *mode))
+{
+  if (!_giza_check_device_ready ("giza_set_motion_callback"))
+    return 1;
+
+  /* assign the motion pointer callback */
+  Dev[id].motion_callback = func;
+
+  return 0;
+}
+
+/**
+ * Device: giza_end_motion_callback
+ *
+ * Synopsis: Free the motion callback pointer
+ *
+ * See Also: giza_set_motion_callback
+ *
+ */
+int
+giza_end_motion_callback (void)
+{
+  if (!_giza_check_device_ready ("giza_end_motion_callback"))
+    return 1;
+
+  if (Dev[id].motion_callback != NULL)
+     {
+       Dev[id].motion_callback = NULL;
+       return 0;
+     }
+  else
+     {
+       return 1; /* return error if already null */
+     }
+
+}
+
 /**
  * Returns the cursor position and key press after a key press.
  *
